@@ -3,13 +3,15 @@ Main interface for elastictranscoder service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elastictranscoder import ElasticTranscoderClient
+    from mypy_boto3_elastictranscoder import ElasticTranscoderClient
 
     session = boto3.Session()
 
     client: ElasticTranscoderClient = boto3.client("elastictranscoder")
     session_client: ElasticTranscoderClient = session.client("elastictranscoder")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
