@@ -3,8 +3,11 @@ Main interface for elastictranscoder service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elastictranscoder import (
+
+    from mypy_boto3_elastictranscoder import ElasticTranscoderClient
+    from mypy_boto3_elastictranscoder import (
         ListJobsByPipelinePaginator,
         ListJobsByStatusPaginator,
         ListPipelinesPaginator,
@@ -17,6 +20,7 @@ Usage::
     list_jobs_by_status_paginator: ListJobsByStatusPaginator = client.get_paginator("list_jobs_by_status")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
