@@ -3,14 +3,18 @@ Main interface for elastictranscoder service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elastictranscoder import (
+
+    from mypy_boto3_elastictranscoder import ElasticTranscoderClient
+    from mypy_boto3_elastictranscoder import (
         JobCompleteWaiter,
     )
 
     client: ElasticTranscoderClient = boto3.client("elastictranscoder")
 
     job_complete_waiter: JobCompleteWaiter = client.get_waiter("job_complete")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import TYPE_CHECKING
